@@ -69,6 +69,17 @@ class Simulation:
 
         return super(Simulation, cls).__new__(cls)
 
+    def __repr__(self):
+        return f"Simulation(chid={self.chid},\n" + \
+               f"           meshes={len(self.meshes)},\n" + \
+               f"           obstructions={len(self.obstructions)},\n" if len(self.obstructions) > 0 else "" + \
+               f"           geometries={len(self.geoms)},\n" if len(self.geoms) > 0 else "" + \
+               f"           slices={len(self.slices)},\n" if len(self.slices) > 0 else "" + \
+               f"           plot3d={len(self.data_3d)},\n" if len(self.data_3d) > 0 else "" + \
+               f"           isosurfaces={len(self.isosurfaces)},\n" if len(self.isosurfaces) > 0 else "" + \
+               f"           particles={len(self.particles)},\n" if len(self.particles) > 0 else "" + \
+               f"           devices={len(self.devices)})" if len(self.devices) > 0 else ""
+
     def __init__(self, path: str):
         """
         :param path: Either the path to the directory containing the simulation data or direct path
